from .robotlibcore import DynamicCore, keyword
from .hook import hook_zh